import type { ComputedGetter, ComputedRef, DebuggerOptions, Ref, UnwrapRef } from 'vue';
import type { YMap, YMapEntity, YMapGroupEntity } from '@yandex/ymaps3-types';
import type { Projection } from '@yandex/ymaps3-types/common/types';
/**
 * @description Prevents memory leak on SSR when ref is called outside setup
 */
export declare function safeRef<T = any>(value: T): Ref<UnwrapRef<T>>;
/**
 * @description Prevents memory leak on SSR when computed is called outside setup
 */
export declare function safeComputed<T>(getter: ComputedGetter<T>, debugOptions?: DebuggerOptions): ComputedRef<T>;
export declare function sleep(ms: number): Promise<unknown>;
export declare function injectMap(): Ref<YMap | null>;
export declare function injectLayers(): Ref<any[]>;
export declare function waitTillYmapInit(): Promise<void>;
export declare function waitTillMapInit(_map?: Ref<YMap | null>): Promise<void>;
export declare function deleteMapChild({ children, isMercator, root, }: {
    children: YMapEntity<unknown> | Projection;
    isMercator?: boolean;
    root: Ref<YMap | YMapGroupEntity<any> | any[] | null>;
}): void;
export declare function setupMapChildren<T extends YMapEntity<unknown> | Projection, R extends (() => Promise<unknown>)>({ returnOnly, willDeleteByHand, strictMapRoot, requiredImport, createFunction, settings, settingsUpdateIgnoreKeys, isLayer, isMercator, isMapRoot, mapRootRef, duplicateInit, }: {
    /**
     * @description Prevents duplicate provide injections
     */
    duplicateInit?: boolean;
    /**
     * @description Disables onBeforeUnmount hook
     */
    willDeleteByHand?: boolean;
    /**
     * @description Disables children-to-root injection
     */
    returnOnly?: boolean;
    /**
     * @description Requires map root to be present (map root can't be YMap in this case)
     */
    strictMapRoot?: boolean;
    /**
     * @description Sets injected component to be root of children components (array.push/.addChild will be called)
     */
    isMapRoot?: boolean;
    /**
     * @description Allows to use array instead of addChild mapRoot injection
     */
    mapRootRef?: Ref<YMapEntity<any>[]>;
    /**
     * @description Promise to call before calling createFunction. Executes only after Yandex script has been injected
     */
    requiredImport?: R;
    /**
     * @description Function that returns Yandex entity
     */
    createFunction: (neededImport: Awaited<ReturnType<R>>) => T;
    /**
     * @description Entity reactive settings. If passed, will be auto-watched
     */
    settings?: ComputedRef<Record<string, any>>;
    /**
     * @description Allows to not-update specific keys inside of settings watch
     */
    settingsUpdateIgnoreKeys?: string[] | ComputedRef<string[]>;
    /**
     * @description Specifies that entity is a layer children. Will be injected to layer ref instead of root and will skip YandexMap initialization
     */
    isLayer?: boolean;
    /**
     * @description Specifies that entity is a layer children. Will be injected to layer ref instead of root and will skip YandexMap initialization, and will be added in special way to YandexMap
     */
    isMercator?: boolean;
}): Promise<T>;
export declare function isDev(): boolean | undefined;
export declare function throwException({ text, isInternal, }: {
    text: string;
    isInternal?: boolean;
}): never;
